@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# pylint: disable=wrong-import-position
+
 from __future__ import unicode_literals
 from __future__ import print_function
 
@@ -11,7 +13,7 @@ import warnings
 import six
 import requests
 
-# Need to check for curses comparability before performing the rtv imports
+# Need to check for curses compatibility before performing the rtv imports
 try:
     import curses
 except ImportError:
@@ -41,12 +43,12 @@ from .terminal import Terminal
 from .content import RequestHeaderRateLimiter
 from .objects import curses_session, patch_webbrowser
 from .subreddit_page import SubredditPage
-from .exceptions import ConfigError
+from .exceptions import ConfigError, SubredditError
 from .__version__ import __version__
 
-
 _logger = logging.getLogger(__name__)
 
+
 # Pycharm debugging note:
 # You can use pycharm to debug a curses application by launching rtv in a
 # console window (python -m rtv) and using pycharm to attach to the remote
@@ -62,7 +64,7 @@ def main():
     logging.captureWarnings(True)
     if six.PY3:
         # These ones get triggered even when capturing warnings is turned on
-        warnings.simplefilter('ignore', ResourceWarning)  #pylint:disable=E0602
+        warnings.simplefilter('ignore', ResourceWarning)  # pylint:disable=E0602
 
     # Set the terminal title
     if os.getenv('DISPLAY'):
@@ -82,11 +84,9 @@ def main():
     if bindings:
         config.keymap.set_bindings(bindings)
 
-    # Copy the default config file and quit
     if config['copy_config']:
         copy_default_config()
         return
-
     if config['copy_mailcap']:
         copy_default_mailcap()
         return
@@ -122,6 +122,7 @@ def main():
             ('$DISPLAY', os.getenv('DISPLAY')),
             ('$TERM', os.getenv('TERM')),
             ('$XDG_CONFIG_HOME', os.getenv('XDG_CONFIG_HOME')),
+            ('$XDG_DATA_HOME', os.getenv('$XDG_DATA_HOME')),
             ('$RTV_EDITOR', os.getenv('RTV_EDITOR')),
             ('$RTV_URLVIEWER', os.getenv('RTV_URLVIEWER')),
             ('$RTV_BROWSER', RTV_BROWSER),
@@ -193,6 +194,7 @@ def main():
                 reddit = praw.Reddit(user_agent=user_agent,
                                      decode_html_entities=False,
                                      disable_update_check=True,
+                                     timeout=10,  # 10 second request timeout
                                      handler=RequestHeaderRateLimiter())
 
             # Dial the request cache up from 30 seconds to 5 minutes
@@ -205,10 +207,19 @@ def main():
             if config.refresh_token:
                 oauth.authorize()
 
+            page = None
             name = config['subreddit']
             with term.loader('Loading subreddit'):
-                page = SubredditPage(reddit, term, config, oauth, name)
-            if term.loader.exception:
+                try:
+                    page = SubredditPage(reddit, term, config, oauth, name)
+                except Exception as e:
+                    # If we can't load the subreddit that was requested, try
+                    # to load the front page instead so at least the
+                    # application still launches.
+                    _logger.exception(e)
+                    page = SubredditPage(reddit, term, config, oauth, 'front')
+                    raise SubredditError('Unable to load {0}'.format(name))
+            if page is None:
                 return
 
             # Open the supplied submission link before opening the subreddit
@@ -239,4 +250,5 @@ def main():
         if 'reddit' in locals():
             reddit.handler.http.close()
 
+
 sys.exit(main())
