@@ -188,6 +188,7 @@ class Content(object):
             data['gold'] = comment.gilded > 0
             data['author'] = author
             data['flair'] = flair
+            data['hidden'] = False
 
         return data
 
@@ -229,7 +230,7 @@ class Content(object):
         data['gold'] = sub.gilded > 0
         data['nsfw'] = sub.over_18
         data['stickied'] = sub.stickied
-        data['hidden'] = False
+        data['hidden'] = sub.hidden
         data['xpost_subreddit'] = None
         data['index'] = None  # This is filled in later by the method caller
         data['saved'] = sub.saved
@@ -747,7 +748,7 @@ class SubscriptionContent(Content):
             name = 'Popular Subreddits'
             items = reddit.get_popular_subreddits(limit=None)
         else:
-            raise exceptions.SubscriptionError('Invalid type %s', content_type)
+            raise exceptions.SubscriptionError('Invalid type %s' % content_type)
 
         return cls(name, items, loader)
 
@@ -898,7 +899,7 @@ class RequestHeaderRateLimiter(DefaultHandler):
     def request(self, _cache_key, _cache_ignore, _cache_timeout, **kwargs):
         """
         This is a wrapper function that handles the caching of the request.
-        
+
         See DefaultHandler.with_cache for reference.
         """
         if _cache_key:
