@@ -36,6 +36,7 @@ def patch_webbrowser():
     # Add support for browsers that aren't defined in the python standard library
     webbrowser.register('surf', None, webbrowser.BackgroundBrowser('surf'))
     webbrowser.register('vimb', None, webbrowser.BackgroundBrowser('vimb'))
+    webbrowser.register('qutebrowser', None, webbrowser.BackgroundBrowser('qutebrowser'))
 
     # Fix the opera browser, see https://github.com/michael-lazar/rtv/issues/476.
     # By default, opera will open a new tab in the current window, which is
@@ -159,6 +160,7 @@ class LoadScreen(object):
         (praw.errors.InvalidCaptcha, 'Error, captcha required'),
         (praw.errors.InvalidSubreddit, '{0.args[0]}'),
         (praw.errors.PRAWException, '{0.__class__.__name__}'),
+        (requests.exceptions.Timeout, 'HTTP request timed out'),
         (requests.exceptions.RequestException, '{0.__class__.__name__}'),
     ]
 
@@ -288,7 +290,7 @@ class LoadScreen(object):
 
                     # Break up the designated sleep interval into smaller
                     # chunks so we can more responsively check for interrupts.
-                    for _ in range(int(interval/0.01)):
+                    for _ in range(int(interval / 0.01)):
                         # Pressing escape triggers a keyboard interrupt
                         if self._terminal.getch() == self._terminal.ESCAPE:
                             os.kill(os.getpid(), signal.SIGINT)
@@ -456,12 +458,12 @@ class Navigator(object):
                 valid = True
             else:
                 # flip to the direction of movement
-                if ((direction > 0) & (self.inverted is True))\
-                   | ((direction < 0) & (self.inverted is False)):
-                    self.page_index += (self.step * (n_windows-1))
+                if ((direction > 0) & (self.inverted is True)) \
+                        | ((direction < 0) & (self.inverted is False)):
+                    self.page_index += (self.step * (n_windows - 1))
                     self.inverted = not self.inverted
                     self.cursor_index \
-                        = (n_windows-(direction < 0)) - self.cursor_index
+                        = (n_windows - (direction < 0)) - self.cursor_index
 
                 valid = False
                 adj = 0
