@@ -23,11 +23,12 @@ def logged_in(f):
     """
     Decorator for Page methods that require the user to be authenticated.
     """
+
     @wraps(f)
     def wrapped_method(self, *args, **kwargs):
         if not self.reddit.is_oauth_session():
             self.term.show_notification('Not logged in')
-            return
+            return None
         return f(self, *args, **kwargs)
     return wrapped_method
 
@@ -58,7 +59,7 @@ class Page(object):
     def refresh_content(self, order=None, name=None):
         raise NotImplementedError
 
-    def _draw_item(self, window, data, inverted):
+    def _draw_item(self, win, data, inverted):
         raise NotImplementedError
 
     def get_selected_item(self):
@@ -290,9 +291,13 @@ class Page(object):
         Checks the inbox for unread messages and displays a notification.
         """
 
-        inbox = len(list(self.reddit.get_unread(limit=1)))
-        message = 'New Messages' if inbox > 0 else 'No New Messages'
-        self.term.show_notification(message)
+        with self.term.loader('Loading'):
+            messages = self.reddit.get_unread(limit=1)
+            inbox = len(list(messages))
+
+        if self.term.loader.exception is None:
+            message = 'New Messages' if inbox > 0 else 'No New Messages'
+            self.term.show_notification(message)
 
     @PageController.register(Command('COPY_PERMALINK'))
     def copy_permalink(self):
@@ -497,7 +502,8 @@ class Page(object):
             # if the content will fill up the page, given that it is dependent
             # on the size of the terminal.
             self.nav.flip((len(self._subwindows) - 1))
-            return self._draw_content()
+            self._draw_content()
+            return
 
         if self.nav.cursor_index >= len(self._subwindows):
             # Don't allow the cursor to go over the number of subwindows
