@@ -118,12 +118,14 @@ class Terminal(object):
             self._display = display
         return self._display
 
-    @staticmethod
-    def flash():
+    def flash(self):
         """
         Flash the screen to indicate that an action was invalid.
         """
-        return curses.flash()
+        if self.config['flash']:
+            return curses.flash()
+        else:
+            return None
 
     @staticmethod
     def curs_set(val):
@@ -273,7 +275,10 @@ class Terminal(object):
             text = self.clean(text, n_cols)
             params = [] if attr is None else [attr]
             window.addstr(row, col, text, *params)
-        except curses.error as e:
+        except (curses.error, ValueError, TypeError) as e:
+            # Curses handling of strings with invalid null bytes (b'\00')
+            #   python 2: TypeError: "int,int,str"
+            #   python 3: ValueError: "embedded null byte"
             _logger.warning('add_line raised an exception')
             _logger.exception(str(e))
 
@@ -318,7 +323,7 @@ class Terminal(object):
         # Cut off the lines of the message that don't fit on the screen
         box_width = min(box_width, n_cols)
         box_height = min(box_height, n_rows)
-        message = message[:box_height-2]
+        message = message[:box_height - 2]
 
         s_row = (n_rows - box_height) // 2 + v_offset
         s_col = (n_cols - box_width) // 2 + h_offset
@@ -375,13 +380,15 @@ class Terminal(object):
         """
 
         if not self.config['enable_media']:
-            return self.open_browser(url)
+            self.open_browser(url)
+            return
 
         try:
             with self.loader('Checking link', catch_exception=False):
                 command, entry = self.get_mailcap_entry(url)
         except exceptions.MailcapEntryNotFound:
-            return self.open_browser(url)
+            self.open_browser(url)
+            return
 
         _logger.info('Executing command: %s', command)
         needs_terminal = 'needsterminal' in entry
@@ -731,7 +738,7 @@ class Terminal(object):
         n_rows, n_cols = self.stdscr.getmaxyx()
         v_offset, h_offset = self.stdscr.getbegyx()
         ch, attr = str(' '), self.attr('Prompt')
-        prompt = self.clean(prompt, n_cols-1)
+        prompt = self.clean(prompt, n_cols - 1)
 
         # Create a new window to draw the text at the bottom of the screen,
         # so we can erase it when we're done.
@@ -809,7 +816,7 @@ class Terminal(object):
 
         # Prune empty lines at the bottom of the textbox.
         for item in stack[::-1]:
-            if len(item) == 0:
+            if not item:
                 stack.pop()
             else:
                 break
@@ -872,7 +879,7 @@ class Terminal(object):
         Check that the terminal supports the provided theme, and applies
         the theme to the terminal if possible.
 
-        If the terminal doesn't support the theme, this falls back to the 
+        If the terminal doesn't support the theme, this falls back to the
         default theme. The default theme only requires 8 colors so it
         should be compatible with any terminal that supports basic colors.
         """
