@@ -4,10 +4,12 @@ from __future__ import unicode_literals
 import curses
 
 import six
+import pytest
 
 from rtv import __version__
 from rtv.subreddit_page import SubredditPage
 from rtv.packages.praw.errors import NotFound, HTTPException
+from requests.exceptions import ReadTimeout
 
 try:
     from unittest import mock
@@ -387,6 +389,21 @@ def test_subreddit_open_subscriptions(subreddit_page, refresh_token):
         assert loop.called
 
 
+def test_subreddit_get_inbox_timeout(subreddit_page, refresh_token, terminal, vcr):
+    if vcr.record_mode == 'none':
+        pytest.skip('Unable to test ReadTimeout exceptions using a cassette')
+
+    # Log in
+    subreddit_page.config.refresh_token = refresh_token
+    subreddit_page.oauth.authorize()
+
+    subreddit_page.reddit.config.timeout = 0.00000001
+    subreddit_page.controller.trigger('i')
+    text = 'HTTP request timed out'.encode('utf-8')
+    terminal.stdscr.subwin.addstr.assert_called_with(1, 1, text)
+    assert isinstance(terminal.loader.exception, ReadTimeout)
+
+
 def test_subreddit_open_multireddits(subreddit_page, refresh_token):
 
     # Log in
@@ -470,3 +487,35 @@ def test_subreddit_frontpage_toggle(subreddit_page, terminal):
         assert subreddit_page.content.name == '/r/aww'
         subreddit_page.controller.trigger('p')
         assert subreddit_page.content.name == '/r/front'
+
+
+def test_subreddit_hide_submission(subreddit_page, refresh_token):
+
+    # Log in
+    subreddit_page.config.refresh_token = refresh_token
+    subreddit_page.oauth.authorize()
+
+    # The api won't return hidden posts in the submission listing, so the
+    # first post should always have hidden set to false
+    data = subreddit_page.get_selected_item()
+    assert data['hidden'] is False
+
+    # Hide the first submission by pressing the space key
+    subreddit_page.controller.trigger(0x20)
+    assert subreddit_page.term.loader.exception is None
+    data = subreddit_page.get_selected_item()
+    assert data['hidden'] is True
+
+    # Make sure that the status was actually updated on the server side
+    data['object'].refresh()
+    assert data['object'].hidden is True
+
+    # Now undo the hide by pressing space again
+    subreddit_page.controller.trigger(0x20)
+    assert subreddit_page.term.loader.exception is None
+    data = subreddit_page.get_selected_item()
+    assert data['hidden'] is False
+
+    # Make sure that the status was actually updated on the server side
+    data['object'].refresh()
+    assert data['object'].hidden is False
\ No newline at end of file
