@@ -93,6 +93,13 @@ def test_terminal_functions(terminal):
     terminal.stdscr.addch.assert_called_with(3, 5, 'ch', 'attr')
 
 
+def test_terminal_no_flash(terminal):
+
+    terminal.config['flash'] = False
+    terminal.flash()
+    assert not curses.flash.called
+
+
 def test_terminal_clean_ascii(terminal):
 
     terminal.config['ascii'] = True
@@ -662,4 +669,4 @@ def test_set_theme_no_colors(terminal, stdscr):
         assert not terminal.theme.use_color
 
         terminal.set_theme(Theme(use_color=True))
-        assert not terminal.theme.use_color
\ No newline at end of file
+        assert not terminal.theme.use_color
